@@ -1,5 +1,7 @@
 mod geometry;
 mod point;
+mod polygon;
 
 pub use geometry::Geometry;
 pub use point::Point;
+pub use polygon::Polygon;
